==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/TrafficPolicyPortTrafficPolicyBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TrafficPolicyPortTrafficPolicyBuilder extends TrafficPolicyPortTrafficPolicyFluentImpl<TrafficPolicyPortTrafficPolicyBuilder> implements VisitableBuilder<TrafficPolicyPortTrafficPolicy,TrafficPolicyPortTrafficPolicyBuilder>{
  public TrafficPolicyPortTrafficPolicyBuilder() {
    this(false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(Boolean validationEnabled) {
    this(new TrafficPolicyPortTrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TrafficPolicyPortTrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent,TrafficPolicyPortTrafficPolicy instance) {
    this(fluent, instance, false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent,TrafficPolicyPortTrafficPolicy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConnectionPool(instance.getConnectionPool());
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withOutlierDetection(instance.getOutlierDetection());
      fluent.withPort(instance.getPort());
      fluent.withTls(instance.getTls());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicy instance) {
    this(instance,false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicy instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConnectionPool(instance.getConnectionPool());
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withOutlierDetection(instance.getOutlierDetection());
      this.withPort(instance.getPort());
      this.withTls(instance.getTls());
    }
    this.validationEnabled = validationEnabled; 
  }
  TrafficPolicyPortTrafficPolicyFluent<?> fluent;
  Boolean validationEnabled;
  public TrafficPolicyPortTrafficPolicy build() {
    TrafficPolicyPortTrafficPolicy buildable = new TrafficPolicyPortTrafficPolicy(fluent.getConnectionPool(),fluent.getLoadBalancer(),fluent.getOutlierDetection(),fluent.getPort(),fluent.getTls());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/TrafficPolicyPortTrafficPolicyBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TrafficPolicyPortTrafficPolicyBuilder extends TrafficPolicyPortTrafficPolicyFluent<TrafficPolicyPortTrafficPolicyBuilder> implements VisitableBuilder<TrafficPolicyPortTrafficPolicy,TrafficPolicyPortTrafficPolicyBuilder>{
  public TrafficPolicyPortTrafficPolicyBuilder() {
    this(false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(Boolean validationEnabled) {
    this(new TrafficPolicyPortTrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TrafficPolicyPortTrafficPolicy(), validationEnabled);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent,TrafficPolicyPortTrafficPolicy instance) {
    this(fluent, instance, false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicyFluent<?> fluent,TrafficPolicyPortTrafficPolicy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new TrafficPolicyPortTrafficPolicy());

    if (instance != null) {
      fluent.withConnectionPool(instance.getConnectionPool());
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withOutlierDetection(instance.getOutlierDetection());
      fluent.withPort(instance.getPort());
      fluent.withTls(instance.getTls());
      fluent.withConnectionPool(instance.getConnectionPool());
      fluent.withLoadBalancer(instance.getLoadBalancer());
      fluent.withOutlierDetection(instance.getOutlierDetection());
      fluent.withPort(instance.getPort());
      fluent.withTls(instance.getTls());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicy instance) {
    this(instance,false);
  }
  public TrafficPolicyPortTrafficPolicyBuilder(TrafficPolicyPortTrafficPolicy instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new TrafficPolicyPortTrafficPolicy());

    if (instance != null) {
      this.withConnectionPool(instance.getConnectionPool());
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withOutlierDetection(instance.getOutlierDetection());
      this.withPort(instance.getPort());
      this.withTls(instance.getTls());
      this.withConnectionPool(instance.getConnectionPool());
      this.withLoadBalancer(instance.getLoadBalancer());
      this.withOutlierDetection(instance.getOutlierDetection());
      this.withPort(instance.getPort());
      this.withTls(instance.getTls());
    }
    this.validationEnabled = validationEnabled; 
  }
  TrafficPolicyPortTrafficPolicyFluent<?> fluent;
  Boolean validationEnabled;
  public TrafficPolicyPortTrafficPolicy build() {
    TrafficPolicyPortTrafficPolicy buildable = new TrafficPolicyPortTrafficPolicy(fluent.buildConnectionPool(),fluent.buildLoadBalancer(),fluent.buildOutlierDetection(),fluent.buildPort(),fluent.buildTls());
    return buildable;
  }
  
}
